# list.pagination.js
A pagination plugin for List.js

## Documentation
Go to [Listjs.com/docs/plugins/pagination](http://listjs.com/docs/plugins/pagination).

## Contribute
Read the guide at [Listjs.com/overview/contribute](http://listjs.com/overview/contribute).

## License
MIT
